Sybase — SQLAlchemy 0.5.6 Documentation

# SQLAlchemy 0.5.6 Documentation

Search:
Version: 0.5.6 Last Updated: 09/13/2009 10:45:11

# Sybase

Sybase database backend.

Known issues / TODO:

> - Uses the mx.ODBC driver from egenix (version 2.1.0)

> - The current version of sqlalchemy.databases.sybase only supports mx.ODBC.Windows (other platforms such as mx.ODBC.unixODBC still need some development)

> - Support for pyodbc has been built in but is not yet complete (needs further development)

> - Results of running tests/alltests.py:

>     Ran 934 tests in 287.032s FAILED (failures=3, errors=1)

> - Tested on ‘Adaptive Server Anywhere 9’ (version 9.0.1.1751)